# BIP

Binary Inside Picture

## Hide binary inside of binary with BIP

Want to hide a file inside of another file? Use BIP. BIP can inject any binary file into another binary file. Hide a .exe in a .png, or a .zip inside a .jpg.

```
Usage: bip [OPTIONS] COMMAND [ARGS]...

Options:
  --help  Show this message and exit.

Commands:
  cleanse  Remove any binary from file
  eject    Save injected binary from a picture
  inject   Inject binary into a picture
```

## To Do

- AES Encryption
- More soon.